@@ -92,10 +92,10 @@ class Subtitle:
         return False
 
     def __repr__(self):
-        return '{}{}{} --> {}{}{}'.format(
-                self.number, os.linesep,
+        return '{}\n{} --> {}\n{}'.format(
+                self.number,
                 self.time_start, self.time_end,
-                os.linesep, os.linesep.join(self.content)
+                '\n'.join(self.content)
         )
 
 
@@ -174,12 +174,12 @@ def process_file(args, file, expressions):
         i += 1
 
     # Join Subtitle objects back to a string
-    contents = (os.linesep + os.linesep).join(map(repr, subs_objs))
+    contents = '\n\n'.join(map(repr, subs_objs))
 
     # Write output
     output = open(file.name, 'w', encoding='utf-8')
     output.write(contents)
-    output.write(os.linesep)
+    output.write('\n')
     output.close()
 
 
